package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.core.domain.entity.SysDept;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.EtFeeRule;
import com.ruoyi.system.service.IEtFeeRuleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 收费方式Controller
 *
 * @author 邱贞招
 * @date 2024-04-08
 */
@RestController
@RequestMapping("/system/fee")
public class EtFeeRuleController extends BaseController
{
    @Autowired
    private IEtFeeRuleService etFeeRuleService;

    /**
     * 查询收费方式列表
     */
    @PreAuthorize("@ss.hasPermi('system:fee:list')")
    @GetMapping("/list")
    public TableDataInfo list(EtFeeRule etFeeRule)
    {
        startPage();
        List<EtFeeRule> list = etFeeRuleService.selectEtFeeRuleList(etFeeRule);
        return getDataTable(list);
    }

    /**
     * 导出收费方式列表
     */
    @PreAuthorize("@ss.hasPermi('system:fee:export')")
    @Log(title = "收费方式", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EtFeeRule etFeeRule)
    {
        List<EtFeeRule> list = etFeeRuleService.selectEtFeeRuleList(etFeeRule);
        ExcelUtil<EtFeeRule> util = new ExcelUtil<EtFeeRule>(EtFeeRule.class);
        util.exportExcel(response, list, "收费方式数据");
    }

    /**
     * 获取收费方式详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fee:query')")
    @GetMapping(value = "/{ruleId}")
    public AjaxResult getInfo(@PathVariable("ruleId") Long ruleId)
    {
        return success(etFeeRuleService.selectEtFeeRuleByRuleId(ruleId));
    }

    /**
     * 新增收费方式
     */
    @Log(title = "收费方式", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EtFeeRule etFeeRule)
    {
        logger.info("新增收费方式：{}", JSON.toJSON(etFeeRule));
        // 校验收费方式
        String validationResult = verifyFeeRule(etFeeRule);
        if (validationResult != null) {
            return AjaxResult.error(validationResult); // 校验失败，返回错误信息
        }
        return toAjax(etFeeRuleService.insertEtFeeRule(etFeeRule));
    }

    /**
     * 修改收费方式
     */
    @Log(title = "收费方式", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EtFeeRule etFeeRule)
    {
        logger.info("修改收费方式：{}", JSON.toJSON(etFeeRule));
        String validationResult = verifyFeeRule(etFeeRule);
        if (validationResult != null) {
            return AjaxResult.error(validationResult); // 校验失败，返回错误信息
        }
        return toAjax(etFeeRuleService.updateEtFeeRule(etFeeRule));
    }

    /**
     * 校验 EtFeeRule 的必填项
     */
    private String verifyFeeRule(EtFeeRule etFeeRule) {
        // 校验套餐名称
        if (etFeeRule.getName() == null || etFeeRule.getName().trim().isEmpty()) {
            return "套餐名称为必填项";
        }
        // 校验运营商
        if (etFeeRule.getDeptId() == null) {
            return "代理商为必填项";
        }
        // 校验说明
        if (etFeeRule.getInstructions() == null || etFeeRule.getInstructions().trim().isEmpty()) {
            return "说明为必填项";
        }
        // 校验免费骑行时长
        if (etFeeRule.getFreeRideTime() == null) {
            return "免费骑行为必填项";
        }
        // 校验租赁单位
        if (etFeeRule.getRentalUnit() == null || etFeeRule.getRentalUnit().trim().isEmpty()) {
            return "租赁单位为必填项";
        }
        // 校验计费规则
        if (etFeeRule.getRidingRule() == null || etFeeRule.getRidingRule().trim().isEmpty()) {
            return "计费规则为必填项";
        }
        // 校验计费周期
        if (etFeeRule.getChargingCycle() == null || etFeeRule.getChargingCycle().trim().isEmpty()) {
            return "计费周期为必填项";
        }
        // 校验封顶金额
        if (etFeeRule.getCappedAmount() == null) {
            return "封顶金额为必填项";
        }
        // 如果所有必填项都校验通过，返回 null
        return null;
    }


    /**
     * 删除收费方式
     */
//    @PreAuthorize("@ss.hasPermi('system:fee:remove')")
    @Log(title = "收费方式", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ruleIds}")
    public AjaxResult remove(@PathVariable Long[] ruleIds)
    {
        return toAjax(etFeeRuleService.deleteEtFeeRuleByRuleIds(ruleIds));
    }
}
